==> seedsui-react-5.6.52.tgz: package/lib/TreePicker/Menu/Utils.js <==
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

export default {
  // 获取状态
  getDOM: function getDOM(_ref) {
    var rootRef = _ref.rootRef,
        id = _ref.id;
    var activeId = id;
    var current = rootRef.current.querySelector("[data-id='".concat(activeId, "']"));
    return current;
  },
  // 重置class
  clearClass: function clearClass(_ref2) {
    var rootRef = _ref2.rootRef,
        classNames = _ref2.classNames;
    var originActives = rootRef.current.querySelectorAll(".".concat(classNames.join(',.')));

    if (originActives && originActives.length) {
      for (var i = 0, originActive; originActive = originActives[i++];) {
        var _iterator = _createForOfIteratorHelper(classNames),
            _step;

        try {
          for (_iterator.s(); !(_step = _iterator.n()).done;) {
            var className = _step.value;
            originActive.classList.remove(className);
          }
        } catch (err) {
          _iterator.e(err);
        } finally {
          _iterator.f();
        }
      }
    }
  },
  // 获取先辈节点
  getPredecessorDOM: function getPredecessorDOM(_ref3) {
    var rootRef = _ref3.rootRef,
        ids = _ref3.ids,
        list = _ref3.list;
    if (!ids || !ids.length) return null; // 获取所有需要选中展开项

    var nodes = [];

    var _iterator2 = _createForOfIteratorHelper(ids),
        _step2;

    try {
      for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
        var id = _step2.value;
        nodes = nodes.concat(list.getDeepTreePredecessor(id));
        nodes = nodes.concat({
          id: id
        });
      }
    } catch (err) {
      _iterator2.e(err);
    } finally {
      _iterator2.f();
    }

    if (!nodes.length) {
      return null;
    } // 获取所有dom


    var query = [];

    var _iterator3 = _createForOfIteratorHelper(nodes),
        _step3;

    try {
      for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
        var node = _step3.value;
        query.push("[data-id='".concat(node.id, "']"));
      }
    } catch (err) {
      _iterator3.e(err);
    } finally {
      _iterator3.f();
    }

    query = query.join(',');
    return rootRef.current.querySelectorAll(query);
  },
  // 选中先辈并展开
  active: function active(_ref4) {
    var rootRef = _ref4.rootRef,
        value = _ref4.value,
        list = _ref4.list;
    if (!(rootRef !== null && rootRef !== void 0 && rootRef.current) || !list || !list.length) return;
    this.clearClass({
      rootRef: rootRef,
      classNames: ['active', 'expand']
    }); // 获取所有需要选中项, 当前项若展开则收缩

    var current = null; // 当前项

    var currentExpand = true; // 当前项是否展开

    var needActives = null;

    if (Array.isArray(value) && value[0] && (typeof value[0].id === 'string' || typeof value[0].id === 'number')) {
      current = this.getDOM({
        rootRef: rootRef,
        id: value[0].id
      }); // 记录点击dom的展开状态

      if (current) {
        currentExpand = current.classList.contains('expand');
      }

      needActives = this.getPredecessorDOM({
        rootRef: rootRef,
        ids: [value[0].id],
        list: list
      });
    } // 选中dom


    if (needActives && needActives.length) {
      for (var i = 0, needActive; needActive = needActives[i++];) {
        needActive.classList.add('active');
        needActive.classList.add('expand');
      }
    } // 点击dom收展


    if (current) {
      if (currentExpand) {
        current.classList.remove('expand');
      } else {
        current.classList.add('expand');
      }
    }
  },
  // 展开关键字
  expandKeyword: function expandKeyword(_ref5) {
    var rootRef = _ref5.rootRef,
        keyword = _ref5.keyword,
        list = _ref5.list;

    if (!(rootRef !== null && rootRef !== void 0 && rootRef.current) || !list || !list.length || keyword === null || keyword === undefined) {
      return;
    } // 取消所有展开项


    this.clearClass({
      rootRef: rootRef,
      classNames: ['expand']
    }); // 如果清空, 则只需要取消所有展开项即可

    if (keyword === '') {
      return;
    } // 获取所有需要选中展开项


    var ids = [];
    var needExpands = null;

    function loop(children) {
      var _iterator4 = _createForOfIteratorHelper(children),
          _step4;

      try {
        for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
          var item = _step4.value;

          if (item.name.indexOf(keyword) !== -1) {
            ids.push(item.id);
          }

          if (Array.isArray(item.children) && item.children.length) {
            loop(item.children);
          }
        }
      } catch (err) {
        _iterator4.e(err);
      } finally {
        _iterator4.f();
      }
    }

    loop(list);
    needExpands = this.getPredecessorDOM({
      rootRef: rootRef,
      ids: ids,
      list: list
    }); // 选中dom

    if (needExpands && needExpands.length) {
      for (var i = 0, needExpand; needExpand = needExpands[i++];) {
        needExpand.classList.add('expand');
      }
    }
  }
};

==> seedsui-react-5.6.70.tgz: package/lib/TreePicker/Menu/Utils.js <==
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
export default {
  // 获取状态
  getDOM: function getDOM(_ref) {
    var rootRef = _ref.rootRef,
      id = _ref.id;
    var activeId = id;
    var current = rootRef.current.querySelector("[data-id='".concat(activeId, "']"));
    return current;
  },
  // 重置class
  clearClass: function clearClass(_ref2) {
    var rootRef = _ref2.rootRef,
      classNames = _ref2.classNames;
    var originActives = rootRef.current.querySelectorAll(".".concat(classNames.join(',.')));
    if (originActives && originActives.length) {
      for (var i = 0, originActive; originActive = originActives[i++];) {
        var _iterator = _createForOfIteratorHelper(classNames),
          _step;
        try {
          for (_iterator.s(); !(_step = _iterator.n()).done;) {
            var className = _step.value;
            originActive.classList.remove(className);
          }
        } catch (err) {
          _iterator.e(err);
        } finally {
          _iterator.f();
        }
      }
    }
  },
  // 获取先辈节点
  getPredecessorDOM: function getPredecessorDOM(_ref3) {
    var rootRef = _ref3.rootRef,
      ids = _ref3.ids,
      list = _ref3.list;
    if (!ids || !ids.length) return null;
    // 获取所有需要选中展开项
    var nodes = [];
    var _iterator2 = _createForOfIteratorHelper(ids),
      _step2;
    try {
      for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
        var id = _step2.value;
        nodes = nodes.concat(list.getDeepTreePredecessor(id));
        nodes = nodes.concat({
          id: id
        });
      }
    } catch (err) {
      _iterator2.e(err);
    } finally {
      _iterator2.f();
    }
    if (!nodes.length) {
      return null;
    }
    // 获取所有dom
    var query = [];
    var _iterator3 = _createForOfIteratorHelper(nodes),
      _step3;
    try {
      for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
        var node = _step3.value;
        query.push("[data-id='".concat(node.id, "']"));
      }
    } catch (err) {
      _iterator3.e(err);
    } finally {
      _iterator3.f();
    }
    query = query.join(',');
    return rootRef.current.querySelectorAll(query);
  },
  // 选中先辈并展开
  active: function active(_ref4) {
    var rootRef = _ref4.rootRef,
      value = _ref4.value,
      list = _ref4.list;
    if (!(rootRef !== null && rootRef !== void 0 && rootRef.current) || !list || !list.length) return;
    this.clearClass({
      rootRef: rootRef,
      classNames: ['active', 'expand']
    });

    // 获取所有需要选中项, 当前项若展开则收缩
    var current = null; // 当前项
    var currentExpand = true; // 当前项是否展开
    var needActives = null;
    if (Array.isArray(value) && value[0] && (typeof value[0].id === 'string' || typeof value[0].id === 'number')) {
      current = this.getDOM({
        rootRef: rootRef,
        id: value[0].id
      });
      // 记录点击dom的展开状态
      if (current) {
        currentExpand = current.classList.contains('expand');
      }
      needActives = this.getPredecessorDOM({
        rootRef: rootRef,
        ids: [value[0].id],
        list: list
      });
    }

    // 选中dom
    if (needActives && needActives.length) {
      for (var i = 0, needActive; needActive = needActives[i++];) {
        needActive.classList.add('active');
        needActive.classList.add('expand');
      }
    }

    // 点击dom收展
    if (current) {
      if (currentExpand) {
        current.classList.remove('expand');
      } else {
        current.classList.add('expand');
      }
    }
  },
  // 展开关键字
  expandKeyword: function expandKeyword(_ref5) {
    var rootRef = _ref5.rootRef,
      keyword = _ref5.keyword,
      list = _ref5.list;
    if (!(rootRef !== null && rootRef !== void 0 && rootRef.current) || !list || !list.length || keyword === null || keyword === undefined) {
      return;
    }

    // 取消所有展开项
    this.clearClass({
      rootRef: rootRef,
      classNames: ['expand']
    });

    // 如果清空, 则只需要取消所有展开项即可
    if (keyword === '') {
      return;
    }

    // 获取所有需要选中展开项
    var ids = [];
    var needExpands = null;
    function loop(children) {
      var _iterator4 = _createForOfIteratorHelper(children),
        _step4;
      try {
        for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
          var item = _step4.value;
          if (item.name.indexOf(keyword) !== -1) {
            ids.push(item.id);
          }
          if (Array.isArray(item.children) && item.children.length) {
            loop(item.children);
          }
        }
      } catch (err) {
        _iterator4.e(err);
      } finally {
        _iterator4.f();
      }
    }
    loop(list);
    needExpands = this.getPredecessorDOM({
      rootRef: rootRef,
      ids: ids,
      list: list
    });

    // 选中dom
    if (needExpands && needExpands.length) {
      for (var i = 0, needExpand; needExpand = needExpands[i++];) {
        needExpand.classList.add('expand');
      }
    }
  }
};
